package com.YuyeTech.TPlat.service;

import com.YuyeTech.TPlat.dataobject.RecentlyPlaying;
import org.springframework.data.domain.Pageable;

import java.util.Map;

/**
 * @author:slambb
 * @date:2020/1/14
 */
public interface RecentlyPlayingService {
    RecentlyPlaying findByUserIdAndFObjectId(String userId, String fObjectId);

    /**
     * 添加最近玩的项目
     * @param recentlyItem
     * @return
     */
    RecentlyPlaying addRecentlyItem(RecentlyPlaying recentlyItem);



    Map findByUserId(String userId, Integer recentlyType, Pageable pageable);

    Map findByUserIdAndPlatform(String userId, Integer recentlyType, Integer platform, Pageable pageable);

}
